==> haskell-wl-pprint-extras-3.5.0.5-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-7s6kyZfKNK43VURIjUPNpu
key: wl-pprint-extras-3.5.0.5-7s6kyZfKNK43VURIjUPNpu
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: 7cefdff8c9f5dd04d552645ef60b0abe
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-7s6kyZfKNK43VURIjUPNpu
depends:
    base-4.10.1.0 containers-0.5.10.2
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    semigroupoids-5.2.1-159o3FQm8wLAkIaxuoQCLq
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             semigroupoids-5.2.1-159o3FQm8wLAkIaxuoQCLq=b68b1907ab7e61c87589c79096b0d5d2
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-J4rCZIfjJ4s5dTcusPK3s2
key: wl-pprint-extras-3.5.0.5-J4rCZIfjJ4s5dTcusPK3s2
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: 4a3ab7df50d809587e903d6fe1cb775c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-J4rCZIfjJ4s5dTcusPK3s2
depends:
    base-4.10.1.0 containers-0.5.10.2
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    semigroupoids-5.2.1-79jkPalWVyGb7DjZeFx7j
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             semigroupoids-5.2.1-79jkPalWVyGb7DjZeFx7j=c9b55a6a191c77fd98bceba152e5fa5d
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
